# VGenEval

load prompts from VideoGen-Eval

## install

pip install VGenEval

## usage

```python
from VGenEval import load_prompt
prompts = load_prompt.get_prompts(ids, model_name)
```

## reference
https://github.com/AILab-CVC/VideoGen-Eval
```
